# variousconnector
handy tools to connect the various data sources

## What are the Key Features?
1. Support PostgreSQL with SSH functionality.
	
## How to Install?

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install.

```bash
pip install variousconnector
```

## How to Use?

### PostgreSQL 

```python
# will update quickly
```